<?php

namespace Hovornyan\Intro\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Hovornyan\Intro\Models\Rea;

class ReaPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the rea.
     *
     * @param User $user
     * @param Rea $rea
     *
     * @return bool
     */
    public function view(User $user, Rea $rea)
    {
        if ($user->canDo('intro.rea.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $rea->user_id;
    }

    /**
     * Determine if the given user can create a rea.
     *
     * @param User $user
     * @param Rea $rea
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('intro.rea.create');
    }

    /**
     * Determine if the given user can update the given rea.
     *
     * @param User $user
     * @param Rea $rea
     *
     * @return bool
     */
    public function update(User $user, Rea $rea)
    {
        if ($user->canDo('intro.rea.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $rea->user_id;
    }

    /**
     * Determine if the given user can delete the given rea.
     *
     * @param User $user
     * @param Rea $rea
     *
     * @return bool
     */
    public function delete(User $user, Rea $rea)
    {
        if ($user->canDo('intro.rea.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $rea->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
